Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8)

Unified Diff: include/gpu/GrContext.h

Issue 2138083002: skip call to clip::apply when clip is wide open Base URL: https://chromium.googlesource.com/skia.git@llist
Patch Set: rm gcmm Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/gpu/GrClip.h ('k') | include/gpu/GrDrawContext.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/gpu/GrContext.h
diff --git a/include/gpu/GrContext.h b/include/gpu/GrContext.h
index f9d06f097a679bc9f12826d185e2af00fc2b6194..daaf90687c4c2edeac836a4e27946a6dee322abc 100644
--- a/include/gpu/GrContext.h
+++ b/include/gpu/GrContext.h
@@ -441,8 +441,8 @@ private:
GrAuditTrail fAuditTrail;
- // TODO: have the CMM use drawContexts and rm this friending
- friend class GrClipMaskManager; // the CMM is friended just so it can call 'drawingManager'
+ // TODO: have the ClipStackClip use drawContexts and rm this friending
+ friend class GrClipStackClip; // this is friended just so it can call 'drawingManager'
friend class GrDrawingManager; // for access to drawingManager for ProgramUnitTest
GrDrawingManager* drawingManager() { return fDrawingManager; }
« no previous file with comments | « include/gpu/GrClip.h ('k') | include/gpu/GrDrawContext.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698